@@ -4,6 +4,7 @@ import uuid
 import random
 import math
 from datetime import datetime
+import re
 
 
 def gen_uuid():
@@ -30,3 +31,17 @@ def gen_phone():
     return phone
 
 
+def is_url(text):
+    regex = re.compile(
+        r'^(?:http|ftp)s?://'  # http:// or https://
+        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'  # domain...
+        r'localhost|'  # localhost...
+        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
+        r'(?::\d+)?'  # optional port
+        r'(?:/?|[/?]\S+)$', re.IGNORECASE)
+    m = regex.match(text)
+
+    if m == None:
+        return False
+    else:
+        return True
\ No newline at end of file
